<?php
/**
 * Default theme options.
 *
 * @package Trade_Line
 */

if ( ! function_exists( 'trade_line_get_default_theme_options' ) ) :

	/**
	 * Get default theme options
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
	function trade_line_get_default_theme_options() {

		$defaults = array();

		// Header.
		$defaults['show_title']                 = true;
		$defaults['show_tagline']               = true;
		$defaults['enable_sticky_primary_menu'] = false;
		$defaults['social_in_header']           = true;
		$defaults['search_in_header']           = true;
		$defaults['header_layout']              = 'layout-1';

		// Search.
		$defaults['search_placeholder'] = esc_html__( 'Search...', 'trade-line-pro' );

		// Layout.
		$defaults['site_layout']             = 'boxed';
		$defaults['global_layout']           = 'right-sidebar';
		$defaults['archive_layout']          = 'full';
		$defaults['archive_image']           = 'large';
		$defaults['archive_image_alignment'] = 'center';
		$defaults['single_image']            = 'large';
		$defaults['single_image_alignment']  = 'center';

		// Home Page.
		$defaults['home_content_status'] = true;

		// Pagination.
		$defaults['pagination_type'] = 'default';

		// Content Meta.
		$defaults['show_meta_date']       = true;
		$defaults['show_meta_author']     = true;
		$defaults['show_meta_categories'] = true;
		$defaults['show_meta_tags']       = true;
		$defaults['show_meta_comment']    = true;

		// Footer.
		$defaults['copyright_text']       = esc_html__( 'Copyright &copy; [the-year] [the-site-link]. All rights reserved.', 'trade-line-pro' );
		$defaults['powered_by_text']      = esc_html__( 'Trade Line Pro by', 'trade-line-pro' ) . ' <a target="_blank" rel="designer" href="https://wenthemes.com/">WEN Themes</a>';
		$defaults['reset_footer_content'] = false;
		$defaults['go_to_top']            = true;


		// Blog.
		$defaults['excerpt_length']  = 40;
		$defaults['read_more_text']  = esc_html__( 'Read More ...', 'trade-line-pro' );
		$defaults['exclude_categories'] = '';

		// Author Bio.
		$defaults['author_bio_in_single']           = true;
		$defaults['author_bio_show_recent_posts']   = false;
		$defaults['author_bio_recent_posts_number'] = 3;

		// Breadcrumb.
		$defaults['breadcrumb_type'] = 'simple';

		// Advanced.
		$defaults['custom_css'] = '';

		// Font.
		$font_keys = trade_line_get_font_family_theme_settings_options();
		if ( ! empty( $font_keys ) ) {
			foreach ( $font_keys as $k => $v ) {
			  $defaults[ $k ]  = $v['default'];
			}
		}
		$defaults['reset_font_settings'] = false;

		// Slider Options.
		$defaults['featured_slider_status']              = 'home-page';
		$defaults['featured_slider_transition_effect']   = 'fadeout';
		$defaults['featured_slider_transition_delay']    = 3;
		$defaults['featured_slider_transition_duration'] = 1;
		$defaults['featured_slider_enable_caption']      = true;
		$defaults['featured_slider_enable_arrow']        = true;
		$defaults['featured_slider_enable_pager']        = true;
		$defaults['featured_slider_enable_autoplay']     = true;
		$defaults['featured_slider_type']                = 'demo-slider';
		$defaults['featured_slider_number']              = 3;
		$defaults['featured_slider_category']            = '';
		$defaults['featured_slider_tag']                 = '';

		// Featured Content Options.
		$defaults['featured_content_status']         = 'home-page';
		$defaults['featured_content_number']         = 3;
		$defaults['featured_content_column']         = 3;
		$defaults['featured_content_type']           = 'demo-content';
		$defaults['featured_content_excerpt_length'] = 40;

		// Featured Clients Options.
		$defaults['featured_clients_status']              = 'home-page';
		$defaults['featured_clients_heading']             = '';
		$defaults['featured_clients_number']              = 7;
		$defaults['featured_clients_enable_new_window']   = true;
		$defaults['featured_clients_enable_arrow']        = true;
		$defaults['featured_clients_enable_autoplay']     = true;
		$defaults['featured_clients_visible_active']      = 6;
		$defaults['featured_clients_transition_delay']    = 3;
		$defaults['featured_clients_enable_non_circular'] = false;
		for ( $i = 1; $i <= $defaults['featured_clients_number']; $i++ ) {
			$defaults['featured_clients_logo_' . $i ] = get_template_directory_uri() . '/images/sample-logo.png';
		}

		// Color.
		$colors = trade_line_get_default_colors();
		if ( ! empty( $colors ) ) {
		  foreach ( $colors as $key => $val ) {
		    $defaults[ $key ] = $val;
		  }
		}


		// Pass through filter.
		$defaults = apply_filters( 'trade_line_filter_default_theme_options', $defaults );
		return $defaults;
	}

endif;
